import logging
import os
from .errors import EnvNotSetError


_logger = logging.getLogger(__name__)


def lookup_env_name(internal_name: str) -> str:
    mapping = {
        "_auth_wsdl": "tg_auth_wsdl",
        "_auth_address": "tg_auth_address",
    }
    return mapping[internal_name]


class TextgridConfig:
    def __init__(self):
        self._auth_wsdl = os.getenv(lookup_env_name("_auth_wsdl"))
        self._auth_address = os.getenv(lookup_env_name("_auth_address"))

    @property
    def auth_wsdl(self):
        if self._auth_wsdl:
            _logger.debug(self._auth_wsdl)
            return self._auth_wsdl
        raise EnvNotSetError(lookup_env_name("_auth_wsdl"))

    @property
    def auth_address(self):
        if self._auth_address:
            return self._auth_address
        raise EnvNotSetError(lookup_env_name("_auth_address"))
