import logging

from wsgidav.dav_provider import DAVCollection, DAVNonCollection, DAVProvider
from wsgidav.util import join_uri

from .tgapi import TextgridAuth

_logger = logging.getLogger(__name__)


class TextgridRootCollection(DAVCollection):
    """top level collection that incorporates so called "projects"

    this is implemented as READ-ONLY as project may not be created with webDAV
    """

    def __init__(self, environ):
        DAVCollection.__init__(self, "/", environ)
        self._sid = environ["wsgidav.auth.user_name"]
        _logger.debug("MY SID: %s", self._sid)
        self._tg_auth = TextgridAuth()
        self._projects = tuple(self._tg_auth.assigned_projects(self._sid))
        _logger.debug("MY PROJECTS: %s", self._projects)

    def get_member_names(self):
        _logger.debug("Called get_member_names(self).")
        return self._projects

    def get_member(self, name):
        _logger.debug("Called get_member(self, name).")
        if name in self._projects:
            return TextgridCollection(join_uri(self.path, name), self.environ)
        return None


class TextgridCollection(DAVCollection):
    def __init__(self, path, environ):
        DAVCollection.__init__(self, path, environ)

    def create_empty_resource(self, name):
        pass

    def create_collection(self, name):
        pass

    def get_member_names(self):
        pass

    def delete(self):
        pass

    def copy_move_single(self, dest_path, is_move):
        pass


class TextgridResource(DAVNonCollection):
    def __init__(self, path, environ):
        DAVNonCollection.__init__(self, path, environ)

    def get_content_length(self):
        pass

    def get_content_type(self):
        pass

    def get_content(self):
        pass

    def begin_write(self, content_type=None):
        pass


# ============================================================================
# TextgridResourceProvider
# ============================================================================
class TextgridResourceProvider(DAVProvider):
    """
    DAV provider that serves Textgrid resources
    """

    def __init__(self):
        super(TextgridResourceProvider, self).__init__()

    def get_resource_inst(self, path, environ):
        _logger.debug("PATH: %s", path)
        _logger.debug("ENVIRON: %s", environ)
        self._count_get_resource_inst += 1
        root = TextgridRootCollection(environ)
        # an instance of _DAVResource (i.e. either DAVCollection or DAVNonCollection)
        return root.resolve("", path)
